@@ -7,7 +7,6 @@
 #### movMF: An R Package for Fitting Mixtures of von Mises-Fisher Distributions
 #### http://cran.r-project.org/web/packages/movMF/vignettes/movMF.pdf
 ################################
-
 rmixvmf <- function(n, prob, mu, k) {
   ## n is the sample size
   ## prob is a vector with the mixing probabilities
@@ -21,7 +20,7 @@ rmixvmf <- function(n, prob, mu, k) {
   ina <- sort(ina)
   nu <- tabulate(ina)  ## frequency table of each cluster
   y <- array( dim = c(n, p, g) )
-  for (j in 1:g)  y[1:nu[j], , j] <- rvmf(nu[j], mu[j, ], k[j])
+  for (j in 1:g)  y[1:nu[j], , j] <- Rfast::rvmf(nu[j], mu[j, ], k[j])
   x <- y[1:nu[1], , 1]
   for (j in 2:g)  x <- rbind(x, y[1:nu[j], , j])  ## simulated data
   ## data come from the first cluster, then from the second and so on
