@@ -6,7 +6,6 @@
 
 vmf.contour <- function(k) {
   ## k is the concentration parameter
-
   rho <- pi/2  ## radius of the circular disc
   x <- seq(-rho, rho, by = 0.01)
   n <- length(x)
@@ -14,11 +13,8 @@ vmf.contour <- function(k) {
   z <- mat + t(mat)
   theta <- sqrt(z)
   ind <- ( theta < rho )  ## checks if x^2+y^2 < rho^2
-  ind[ ind == FALSE ] <- NA
-
-  xa <- 0.5 * log(k) + k * cos(theta) - 1.5 * log(2 * pi) - 
-  log( besselI(k, 0.5, expon.scaled = TRUE) ) - k
+  ind[ !ind ] <- NA
+  xa <- 0.5 * log(k) + k * cos(theta) - 1.5 * log(2 * pi) - log( besselI(k, 0.5, expon.scaled = TRUE) ) - k
   mat <- exp(xa) * ind   
   contour(x, x, mat)
-
 }
\ No newline at end of file
